@@ -4,7 +4,6 @@ import contextlib
 import json
 import logging
 from datetime import timedelta
-from enum import Enum
 from http import HTTPStatus
 from typing import Any
 from typing import ContextManager
@@ -18,10 +17,11 @@ from typing import Union
 
 from autoblocks._impl import global_state
 from autoblocks._impl.config.constants import API_ENDPOINT
-from autoblocks._impl.prompts.constants import LATEST
-from autoblocks._impl.prompts.constants import UNDEPLOYED
+from autoblocks._impl.config.constants import REVISION_LATEST
+from autoblocks._impl.context_vars import RevisionType
+from autoblocks._impl.context_vars import register_revision_usage
 from autoblocks._impl.prompts.context import PromptExecutionContext
-from autoblocks._impl.prompts.error import IncompatiblePromptSnapshotError
+from autoblocks._impl.prompts.error import IncompatiblePromptRevisionError
 from autoblocks._impl.prompts.models import Prompt
 from autoblocks._impl.prompts.models import PromptMinorVersion
 from autoblocks._impl.prompts.models import WeightedMinorVersion
@@ -33,7 +33,6 @@ from autoblocks._impl.util import get_running_loop
 log = logging.getLogger(__name__)
 
 ExecutionContextType = TypeVar("ExecutionContextType", bound=PromptExecutionContext[Any, Any])
-MinorVersionEnumType = TypeVar("MinorVersionEnumType", bound=Enum)
 
 
 def is_testing_context() -> bool:
@@ -47,27 +46,24 @@ def is_testing_context() -> bool:
     return bool(AutoblocksEnvVar.CLI_SERVER_ADDRESS.get())
 
 
-def prompt_snapshots_map() -> dict[str, str]:
+def prompt_revisions_map() -> dict[str, str]:
     """
-    The AUTOBLOCKS_PROMPT_SNAPSHOTS environment variable is a JSON-stringified
-    map of prompt IDs to snapshot IDs. This is set in CI test runs triggered
+    The AUTOBLOCKS_PROMPT_REVISIONS environment variable is a JSON-stringified
+    map of prompt IDs to revision IDs. This is set in CI test runs triggered
     from the UI.
     """
     if not is_testing_context():
         return {}
 
-    prompt_snapshots_raw = AutoblocksEnvVar.PROMPT_SNAPSHOTS.get()
-    if not prompt_snapshots_raw:
+    prompt_revisions_raw = AutoblocksEnvVar.PROMPT_REVISIONS.get()
+    if not prompt_revisions_raw:
         return {}
-    return json.loads(prompt_snapshots_raw)  # type: ignore
+    return json.loads(prompt_revisions_raw)  # type: ignore
 
 
 class AutoblocksPromptManager(
     abc.ABC,
-    Generic[
-        ExecutionContextType,
-        MinorVersionEnumType,
-    ],
+    Generic[ExecutionContextType],
 ):
     __prompt_id__: str
     __prompt_major_version__: str
@@ -86,8 +82,8 @@ class AutoblocksPromptManager(
     def __init__(
         self,
         minor_version: Union[
-            MinorVersionEnumType,
-            List[WeightedMinorVersion[MinorVersionEnumType]],
+            str,
+            List[WeightedMinorVersion],
         ],
         api_key: Optional[str] = None,
         init_timeout: timedelta = timedelta(seconds=30),
@@ -111,7 +107,7 @@ class AutoblocksPromptManager(
 
         self._api_key = api_key
 
-        self._prompt_snapshot: Optional[Prompt] = None
+        self._prompt_revision_override: Optional[Prompt] = None
 
         refresh_seconds = refresh_interval.total_seconds()
         if refresh_seconds < 1:
@@ -119,7 +115,7 @@ class AutoblocksPromptManager(
 
         self._init()
 
-        if LATEST in self._minor_version.all_minor_versions:
+        if REVISION_LATEST in self._minor_version.all_minor_versions:
             if is_testing_context():
                 log.info("Prompt refreshing is disabled when in a testing context.")
                 return
@@ -139,10 +135,10 @@ class AutoblocksPromptManager(
         minor_version = encode_uri_component(minor_version)
         return f"{API_ENDPOINT}/prompts/{prompt_id}/major/{major_version}/minor/{minor_version}"
 
-    def _make_snapshot_validate_override_request_url(self, snapshot_id: str) -> str:
+    def _make_revision_validate_override_request_url(self, revision_id: str) -> str:
         prompt_id = encode_uri_component(self.__prompt_id__)
-        snapshot_id = encode_uri_component(snapshot_id)
-        return f"{API_ENDPOINT}/prompts/{prompt_id}/snapshots/{snapshot_id}/validate"
+        revision_id = encode_uri_component(revision_id)
+        return f"{API_ENDPOINT}/prompts/{prompt_id}/revisions/{revision_id}/validate"
 
     async def _get_prompt(
         self,
@@ -157,33 +153,27 @@ class AutoblocksPromptManager(
         resp.raise_for_status()
         return Prompt.model_validate(resp.json())
 
-    async def _set_prompt_snapshot(self, snapshot_id: str) -> None:
+    async def _set_prompt_revision(self, revision_id: str) -> None:
         """
-        If this prompt has a snapshot set, use the /validate endpoint to check if the
-        major version this prompt manager is configured to use is compatible to be
-        overridden with the snapshot.
+        If this prompt has a revision override set, use the /validate endpoint to
+        check if the major version this prompt manager is configured to use is compatible
+        to be overridden with the revision.
         """
         # Double check we're in a testing context
         if not is_testing_context():
-            log.error("Can't set prompt snapshot unless in a testing context.")
+            log.error("Can't set prompt revision unless in a testing context.")
             return
 
-        # Double check the given snapshot_id belongs to this prompt manager
-        expected_snapshot_id = prompt_snapshots_map()[self.__prompt_id__]
-        if snapshot_id != expected_snapshot_id:
+        # Double check the given revision_id belongs to this prompt manager
+        expected_revision_id = prompt_revisions_map()[self.__prompt_id__]
+        if revision_id != expected_revision_id:
             raise RuntimeError(
-                f"Snapshot ID '{snapshot_id}' does not match the snapshot ID "
-                f"for this prompt manager '{expected_snapshot_id}'."
-            )
-
-        if self.__prompt_major_version__ == UNDEPLOYED:
-            raise NotImplementedError(
-                "Prompt snapshot overrides are not yet supported for prompt managers using DANGEROUSLY_USE_UNDEPLOYED. "
-                "Reach out to support@autoblocks.ai for more details."
+                f"Revision ID '{revision_id}' does not match the revision ID "
+                f"for this prompt manager '{expected_revision_id}'."
             )
 
         resp = await global_state.http_client().post(
-            self._make_snapshot_validate_override_request_url(snapshot_id),
+            self._make_revision_validate_override_request_url(revision_id),
             timeout=self._init_timeout.total_seconds(),
             headers={"Authorization": f"Bearer {self._api_key}"},
             json=dict(
@@ -192,28 +182,28 @@ class AutoblocksPromptManager(
         )
 
         if resp.status_code == HTTPStatus.CONFLICT:
-            # The /validate endpoint returns this status code when the snapshot is
+            # The /validate endpoint returns this status code when the revision is
             # not compatible with the major version this prompt manager
             # is configured to use.
-            raise IncompatiblePromptSnapshotError(
-                f"Can't override '{self._class_name}' with prompt snapshot '{snapshot_id}' because it is not "
+            raise IncompatiblePromptRevisionError(
+                f"Can't override prompt '{self._class_name}' with revision '{revision_id}' because it is not "
                 f"compatible with major version '{self.__prompt_major_version__}'."
             )
 
         # Raise for any unexpected errors
         resp.raise_for_status()
 
-        # Set the prompt snapshot
-        log.warning(f"Overriding '{self._class_name}' with prompt snapshot '{snapshot_id}'!")
-        self._prompt_snapshot = Prompt.model_validate(resp.json())
+        # Set the prompt revision override
+        log.warning(f"Overriding prompt '{self._class_name}' with revision '{revision_id}'!")
+        self._prompt_revision_override = Prompt.model_validate(resp.json())
 
     async def _init_async(self) -> None:
-        # Set the snapshot prompt if this manager's prompt ID is in the snapshot map
-        if is_testing_context() and (snapshot_id := prompt_snapshots_map().get(self.__prompt_id__)):
-            await self._set_prompt_snapshot(snapshot_id)
+        # Set the revision override if this manager's prompt ID is in the revision map
+        if is_testing_context() and (revision_id := prompt_revisions_map().get(self.__prompt_id__)):
+            await self._set_prompt_revision(revision_id)
             return
 
-        # Not in testing context or no snapshot set, proceed as configured
+        # Not in testing context or no revision override set, proceed as configured
 
         # Convert all_minor_versions (which is a set) to a list
         # to guarantee we get the same order both when fetching
@@ -233,7 +223,7 @@ class AutoblocksPromptManager(
             # tuple, not `prompt.minor_version`. This is because the
             # latter will contain the actual version number, which may be
             # different from the minor version we requested (in the case
-            # where we requested LATEST or UNDEPLOYED).
+            # where we requested LATEST).
             self._minor_version_to_prompt[minor_version] = prompt
             log.info(f"Successfully fetched version '{prompt.version}' of prompt '{self.__prompt_id__}'")
 
@@ -275,24 +265,24 @@ class AutoblocksPromptManager(
     async def _refresh_latest(self) -> None:
         # Get the latest minor version within this prompt's major version
         new_latest = await self._get_prompt(
-            minor_version=LATEST,
+            minor_version=REVISION_LATEST,
             timeout=self._refresh_timeout,
         )
 
         # Get the prompt we're replacing
-        old_latest = self._minor_version_to_prompt.get(LATEST)
+        old_latest = self._minor_version_to_prompt.get(REVISION_LATEST)
 
         # Update the prompt
-        self._minor_version_to_prompt[LATEST] = new_latest
+        self._minor_version_to_prompt[REVISION_LATEST] = new_latest
 
         # Log if we're replacing an older version of the prompt
         if old_latest and old_latest.version != new_latest.version:
             log.info(f"Updated latest prompt from v{old_latest.version} to v{new_latest.version}")
 
     def _choose_execution_prompt(self) -> Prompt:
-        # Always use the prompt snapshot if it is set
-        if is_testing_context() and self._prompt_snapshot:
-            return self._prompt_snapshot
+        # Always use the prompt revision override if it is set
+        if is_testing_context() and self._prompt_revision_override:
+            return self._prompt_revision_override
 
         # Choose the minor version to use
         chosen_minor_version = self._minor_version.choose_version()
@@ -325,6 +315,12 @@ class AutoblocksPromptManager(
         @contextlib.contextmanager
         def gen():  # type: ignore
             prompt = self._choose_execution_prompt()
+            if is_testing_context():
+                register_revision_usage(
+                    entity_id=prompt.id,
+                    entity_type=RevisionType.PROMPT,
+                    revision_id=prompt.revision_id,
+                )
             yield self.__execution_context_class__(prompt=prompt)
 
         return gen()
